@@ -19,11 +19,13 @@ import os
 from collections import defaultdict
 from configparser import ConfigParser
 
-from digitalguide import (contextActions, conversationActions, imageActions,
+from digitalguide import (contextActions, imageActions,
                           listenfrageActions, schaetzfragenActions,
                           writeActions)
 
 import logging.config
+
+from digitalguide.telegram import conversationActions
 logger = logging.config.fileConfig("logging.ini")
 logger = logging.getLogger(__name__)
 
@@ -39,10 +41,10 @@ class Bot:
         self.MESSANGER = os.getenv('MESSANGER', 'Telegram')
 
         if self.MESSANGER == "Telegram":
-            from digitalguide.errorHandler import error_handler
-            from digitalguide.generateActions import (callback_query_handler,
+            from digitalguide.telegram.errorHandler import error_handler
+            from digitalguide.telegram.generateActions import (callback_query_handler,
                                                         read_action_yaml)
-            from digitalguide.generateStates import read_state_yml
+            from digitalguide.telegram.generateStates import read_state_yml
             from telegram.ext import (CallbackQueryHandler, CommandHandler,
                                         ConversationHandler, Filters, MessageHandler,
                                         Updater)
@@ -94,12 +96,12 @@ class Bot:
             self.updater.dispatcher.add_error_handler(error_handler)
 
 
-        elif self.MESSANGER == "WhatsApp":
-            from digitalguide.whatsapp.generateActions import read_action_yaml
-            from digitalguide.whatsapp.generateStates import (CommandHandler,
+        elif self.MESSANGER == "Twilio":
+            from digitalguide.twilio.generateActions import read_action_yaml
+            from digitalguide.twilio.generateStates import (CommandHandler,
                                                                 read_state_yml)
-            from digitalguide.whatsapp.WhatsAppUpdate import WhatsAppUpdate
-            from flask import Flask, Response, request
+            from digitalguide.twilio.TwilioUpdate import TwilioUpdate
+            from quart import Quart, Response, request
             from twilio.rest import Client
 
             # Find your Account SID and Auth Token at twilio.com/console
@@ -108,32 +110,32 @@ class Bot:
             auth_token = os.environ['TWILIO_AUTH_TOKEN']
             client = Client(account_sid, auth_token)
 
-            self.app = Flask(__name__)
+            self.app = Quart(__name__)
 
             user_states = defaultdict(lambda: "START_START")
             user_context = defaultdict(dict)
 
-            self.action_functions = {**contextActions.whatsapp_action_functions,
-                                **listenfrageActions.whatsapp_action_functions,
-                                **schaetzfragenActions.whatsapp_action_functions,
-                                **imageActions.whatsapp_action_functions,
-                                **writeActions.whatsapp_action_functions,
+            self.action_functions = {**contextActions.twilio_action_functions,
+                                **listenfrageActions.twilio_action_functions,
+                                **schaetzfragenActions.twilio_action_functions,
+                                **imageActions.twilio_action_functions,
+                                **writeActions.twilio_action_functions,
                                 }
         
             action_functions = {**self.action_functions, **custom_actions}
 
-            general_actions = read_action_yaml("actions/whatsapp_general.yml", action_functions=action_functions)
+            general_actions = read_action_yaml("actions/twilio_general.yml", action_functions=action_functions)
 
             prechecks = [CommandHandler('start', general_actions[config["bot"]["start_action"]]),
                             ]
 
-            general_handler = read_state_yml("states/whatsapp_general.yml", actions={
+            general_handler = read_state_yml("states/twilio_general.yml", actions={
                                                 **general_actions}, prechecks=prechecks)
 
             @self.app.route('/bot', methods=['POST'])
             def bot():
                 print(request.values)
-                update = WhatsAppUpdate(**request.values)
+                update = TwilioUpdate(**request.values)
                 icoming_state = user_states[update.From]
                 context = user_context[update.From]
 
@@ -163,11 +165,11 @@ class Bot:
 
             self.updater.idle()
 
-        if self.MESSANGER == "WhatsApp":
+        if self.MESSANGER == "Twilio":
             logger.error("Please use the create_app method.")
 
     def create_app(self):
         if self.MESSANGER == "Telegram":
             logger.error("Please use the run method.")
-        if self.MESSANGER == "WhatsApp":
+        if self.MESSANGER == "Twilio":
             return self.app
\ No newline at end of file
