@@ -74,6 +74,9 @@ WOHIN_PATTERN = "^("\
     ")$"
 
 JA_PATTERN = "^("\
+    "Macht nichts 😊|"\
+    "Wie süüüß 😍|"\
+    "Kein Problem! 🤗|"\
     "Okay|"\
     "ok|"\
     "okay|"\
