@@ -1,3 +1,4 @@
+import os
 import asyncio
 from collections import defaultdict
 from digitalguide.whatsapp.WhatsAppUpdate import WhatsAppUpdate
@@ -7,7 +8,6 @@ from configparser import ConfigParser
 config = ConfigParser()
 config.read('config.ini')
 
-import os
 
 def read_action_yaml(filename, action_functions={}, log_user=True, log_interaction=True):
     with open(filename) as file:
@@ -16,10 +16,59 @@ def read_action_yaml(filename, action_functions={}, log_user=True, log_interacti
     actions_dict = {}
 
     for key, value in yaml_dict.items():
-        actions_dict[key] = Action(value, action_functions=action_functions, log_user=log_user, log_interaction=log_interaction)
+        actions_dict[key] = Action(
+            value, action_functions=action_functions, log_user=log_user, log_interaction=log_interaction)
 
     return actions_dict
 
+import requests
+import logging
+
+logging.basicConfig(
+    level=logging.INFO,
+    format="%(asctime)s - %(name)s - %(levelname)s - %(message)s",
+)
+
+
+def send_interactive_list(self, recipient_id, body_text, button_text, sections, header_text=None, footer_text=None):
+    """
+    Sends an interactive list message to a WhatsApp user
+    Args:
+        recipient_id[str]: Phone number of the user with country code wihout +
+    check https://github.com/Neurotech-HQ/heyoo#sending-interactive-reply-buttons for an example.
+    """
+    interactive_dict = {}
+    if header_text:
+        interactive_dict["header"] = {"type": "text", "text": header_text}
+    if footer_text:
+        interactive_dict["footer"] = {"text": footer_text}
+    if body_text:
+        interactive_dict["body"] = {"text": body_text}
+
+    interactive_dict["type"]= "list"
+    interactive_dict["action"] = {}
+    interactive_dict["action"]["button"] = button_text
+
+    interactive_dict["action"]["sections"] = sections
+
+    data = {
+        "messaging_product": "whatsapp",
+        "to": recipient_id,
+        "type": "interactive",
+        "interactive": interactive_dict,
+    }
+    logging.info(f"Sending buttons to {recipient_id}")
+    r = requests.post(self.url, headers=self.headers, json=data)
+    if r.status_code == 200:
+        logging.info(f"Buttons sent to {recipient_id}")
+        return r.json()
+    logging.info(f"Buttons not sent to {recipient_id}")
+    logging.info(f"Status code: {r.status_code}")
+    logging.info(f"Response: {r.json()}")
+    return r.json()
+
+
+
 class Action():
     def __init__(self, actions, action_functions={}, log_user=True, log_interaction=True):
         self.actions = actions
@@ -38,8 +87,6 @@ class Action():
             else:
                 mongoengine.connect(alias=dbname, host="mongodb+srv://" + os.getenv("DATABASE_USERNAME")+":" + os.getenv("DATABASE_PASSWORD") +
                                     "@" + os.getenv("DATABASE_HOST") + "/"+dbname+"?authSource=admin&tls=true")
-            
-
 
     async def __call__(self, client, update: WhatsAppUpdate, context):
         if self.log_user and not ("user_id" in context.keys()):
@@ -53,13 +100,10 @@ class Action():
             from digitalguide.whatsapp.db_objects import WhatsAppInteraction
 
             WhatsAppInteraction(user=context["user_id"],
-                            ProfileName = update.entry[0].changes[0].value.contacts[0].profile_name,
-                            WaId = update.get_from(),
-                            text = update.get_message_text(),
-                            ).save()
-
-
-
+                                ProfileName=update.entry[0].changes[0].value.contacts[0].profile_name,
+                                WaId=update.get_from(),
+                                text=update.get_message_text(),
+                                ).save()
 
         for item in self.actions:
             if item["type"] == "return":
@@ -71,32 +115,60 @@ class Action():
                 placeholder_dict["echo"] = update.get_message_text()
 
                 if "reply_buttons" in item.keys():
-                    buttons=[]
+                    buttons = []
+
                     for button in item["reply_buttons"]:
                         buttons.append({
-                                            "type": "reply",
-                                            "reply": {
-                                                "id": button["id"],
-                                                "title": button["text"]
-                                            }
-                                        })
+                            "type": "reply",
+                            "reply": {
+                                "id": button["id"],
+                                "title": button["text"]
+                            }
+                        })
 
-                    button_dict={
-                                "type": "button",
+                    button_dict = {
+                        "type": "button",
                                 "body": {
                                     "text": item["text"].format(**placeholder_dict)
                                 },
-                                "action": {
+                        "action": {
                                     "buttons": buttons
                                 }
-                        }
+                    }
+
+                    if "footer" in item.keys():
+                        button_dict["footer"] = {"text": item["footer"]}
 
                     client.send_reply_button(recipient_id=update.get_from(),
-                                             button = button_dict)
+                                             button=button_dict)
+
+                elif "button" in item.keys() and "section_title" in item.keys():
+                    section_dict= [
+                            {
+                                "title": item["section_title"],
+                                "rows": [],
+                            }
+                        ]
+
+                    for row in item["rows"]:
+                        row_dict = {"id": row["id"],
+                                    "title": row["title"],
+                                    "description": row.get("description", "")}
+                        section_dict[0]["rows"].append(
+                            row_dict)
+
+                    send_interactive_list(client, 
+                        recipient_id=update.get_from(),
+                        body_text=item["text"].format(**placeholder_dict),
+                        button_text=item["button"],
+                        sections = section_dict,
+                        header_text=item.get("header", None),
+                        footer_text=item.get("footer", None))
+
                 else:
                     client.send_message(item["text"].format(
                         **placeholder_dict), update.get_from())
-                
+
             elif item["type"] == "venue":
                 client.send_location(
                     name=item["title"],
@@ -117,11 +189,11 @@ class Action():
                 )
             elif item["type"] == "media_group":
                 pass
-                #message = client.messages.create(
+                # message = client.messages.create(
                 #    media_url=item["urls"],
                 #    from_=update.To,
                 #    to=update.From
-                #)
+                # )
             elif item["type"] == "audio" or item["type"] == "voice":
                 client.send_audio(
                     item["url"],
@@ -137,4 +209,4 @@ class Action():
                 arguments = {i: item[i]
                              for i in item if i != 'type' and i != 'func'}
                 self.action_functions[item["func"]](
-                    client, update, context, **arguments)
\ No newline at end of file
+                    client, update, context, **arguments)
