@@ -6,8 +6,7 @@ def whatsapp_default_name(client, update: WhatsAppUpdate, context):
 
 
 def whatsapp_save_text_to_context(client, update: WhatsAppUpdate, context, key):
-    if update.get_message()._type == "text":
-        context[key] = update.get_message().text
+    context[key] = update.get_message_text()
 
 
 def whatsapp_save_value_to_context(client, update: WhatsAppUpdate, context, key, value):
