@@ -8,7 +8,7 @@ import warnings
 
 def whatsapp_eval_jahreszahl(client, update: WhatsAppUpdate, context, echter_wert, richtig_text, vorher_singular_text, vorher_plural_text, spaeter_singular_text, spaeter_plural_text):
     echter_wert = int(echter_wert)
-    schaetzung = int(re.findall(JAHRESZAHL_PATTERN, update.Body)[0])
+    schaetzung = int(re.findall(JAHRESZAHL_PATTERN, update.get_message_text())[0])
     if schaetzung == echter_wert:
         client.send_message(richtig_text, update.get_from())
 
@@ -35,7 +35,7 @@ def whatsapp_eval_prozentzahl(client, update: WhatsAppUpdate, context, echter_we
 def whatsapp_eval_kommazahl(client, update: WhatsAppUpdate, context, echter_wert, richtig_text, vorher_singular_text, vorher_plural_text, spaeter_singular_text, spaeter_plural_text):
     echter_wert = float(echter_wert)
     match = re.search(
-        KOMMAZAHL_PATTERN, update.Body)
+        KOMMAZAHL_PATTERN, update.get_message_text())
 
     if match:
         if match.group('vorkomma'):
